using Autofac;
using FitConnect.Interfaces.Subscriber;
using FitConnect.Models;
using Microsoft.Extensions.Logging;
using MockContainer;
using NUnit.Framework;

namespace IntegrationTests.Subscriber;

public abstract class SubscriberTestBase {
    protected const string DestinationId = "aa3704d6-8bd7-4d40-a8af-501851f93934";
    private const string ClientId = "20175c2b-c4dd-4a01-99b1-3a08436881a1";
    private const string ClientSecret = "KV2qd7qc5n-xESB6dvfrTlMDx2BWHJd5hXJ6pKKnbEQ";
    private IContainer _container = null!;
    protected ILogger Logger = null!;
    protected ISubscriber Subscriber { get; set; } = null!;

    [OneTimeSetUp]
    public void OneTimeSetUp() {
        // One-time initialization code
        _container = Container.Create();
    }

    [SetUp]
    public void SetUp() {
        // Code here will be called before every test


        Logger = LoggerFactory.Create(b => {
                b.AddConsole();
                b.SetMinimumLevel(LogLevel.Trace);
            })
            .CreateLogger<FitConnect.Sender>();
        Subscriber = new FitConnect.Subscriber(
            FitConnectEnvironment.Testing,
            ClientId,
            ClientSecret,
            _container.Resolve<MockSettings>().PrivateKeyDecryption,
            _container.Resolve<MockSettings>().PrivateKeySigning,
            Logger);
    }


    [TearDown]
    public void TearsDown() {
        // Code here will be called after every test
    }

    [OneTimeTearDown]
    public void OneTimeTearDown() {
        // One-time cleanup code
    }
}
